//
//  EQLCIPCOutgoingMessage.h
//  EQLibC
//
//  Created by Markus Hanauska on 08-04.
//  Copyright 2006 equinux AG. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import "EQLCIPCSocket.h"

#ifdef BUILD_EQ_LIBC_FRAMEWORK
#include "com/equinux/Encapsulation.h"
#include "com/equinux/ipc/IPCOutgoingMessage.h"
#endif

#include "EQLCIPCDataTypes.h"

@interface EQLCIPCOutgoingMessage : NSObject {
#ifdef BUILD_EQ_LIBC_FRAMEWORK
	com_equinux_ipc_OutgoingMessage outMessage;
#else
	void * outMessage;
#endif

}


+ (id) outgoingMessageWithKind:(u_int32_t)kind andPriority:(u_int8_t)prio;
- (id) initWithKind:(u_int32_t)kind andPriority:(u_int8_t)prio;


// Add a parameter to the package - if false, probably out of memory
- (BOOL) addParameter:(u_int16_t)paramNumber 
	ofValue:(void *)value andType:(EQLCIPCDataType)type;

// Just get these values
- (u_int8_t) priority;
- (u_int32_t) kind;

// Sequence number, counts upwards with every message created
- (u_int32_t) sequenceNumber;

// Sends the message over the socket to another proccess
- (NSError *) sendOverSocket:(EQLCIPCSocket *)soc;


/* Possible error codes for NSError:
 * 
 *  Unknown error:
 * 	CEN_(Socket_Exception_SocketError)
 *
 *  Operation would block, but socket is set to non-blocking:
 *  CEN_(Socket_Exception_WouldBlock)
 *
 *  The operation requested only works on a connected socket, this one is not:
 *  CEN_(Socket_Exception_NotConnected)
 *
 *  The last operation was interrupted by anonther proccess or thread:
 *  CEN_(Socket_Exception_SignalInterrupt)
 *
 *  The system says you don't have sufficient privileges for this operation:
 *  CEN_(Socket_Exception_PermissionDenied)
 *
 *  The message is too large for this kind of socket
 *  CEN_(Socket_Exception_DataTooLarge)
 *
 * CEN_() is a macro that expands to "com_equinux_net_".
 * If no error happens, NSError return will be "nil".
 */


@end
