/*
 *  EQLCKeychainManager.h
 *  EQLibCFramework
 *
 *  Created by Markus Hanauska on 2006-11-21.
 *  Copyright 2006 equinux AG. All rights reserved.
 *
 */

#import <Cocoa/Cocoa.h>
#import "EQLCKeychainItem.h"

#ifdef BUILD_EQ_LIBC_FRAMEWORK
#include "com/equinux/osx/sec/KeychainManager.h"
#endif

@interface EQLCKeychainManager : NSObject {
#ifdef BUILD_EQ_LIBC_FRAMEWORK
	com_equinux_osx_sec_KeychainManager _manager;
#else
	void * _manager;
#endif

}

+ (id) defaultKeychainManager;


- (id) init;


// Stores "item" in Database
// Update will update an already existing item. If item has been retrieved
// from the database, it will update the retrieved item, if not,
// it will search for an item and update the first found item, if any.
// If update is false, it will create a new item even if item was previously
// retrieved from the database (may lead to a duplicate item if nothing has
// been modified)
- (BOOL) storeInDatabase:(EQLCKeychainItem *)item update:(BOOL)doIt;

// Deletes "item" in Database
// If item has been retrieved from database, deletes exactly this item.
// If not, starts a search for a matching item and deletes first item found.
- (BOOL) deleteFromDatabase:(EQLCKeychainItem *)item;

// Retrieves all matching items from database
- (NSArray *) retrieveAllFromDatabase:(EQLCKeychainItem *)pattern;

// Checks if entry is found without actually retrieving it.
// This way we can check for an entry without triggering any dialogs.
- (BOOL) existsInDatabase:(EQLCKeychainItem *)pattern;

// Retrieves exactly one entry, if multiple match, picks the first one found
- (EQLCKeychainItem *) retrieveFromDatabase:(EQLCKeychainItem *)pattern;


@end
